type BlobInput = ReadableStream | string | ArrayBuffer | Blob;
type Fetcher = typeof globalThis.fetch;
declare enum HTTPMethod {
    DELETE = "delete",
    GET = "get",
    PUT = "put"
}

interface Context {
    apiURL?: string;
    edgeURL?: string;
    siteID?: string;
    token?: string;
}
interface MakeStoreRequestOptions {
    body?: BlobInput | null;
    headers?: Record<string, string>;
    key: string;
    method: HTTPMethod;
    storeName: string;
}
declare class Client {
    private context?;
    private fetch?;
    constructor(context?: Context, fetch?: Fetcher);
    private static getEnvironmentContext;
    private getContext;
    private getFinalRequest;
    makeRequest({ body, headers: extraHeaders, key, method, storeName }: MakeStoreRequestOptions): Promise<Response | null>;
}

interface BaseStoreOptions {
    client: Client;
}
interface DeployStoreOptions extends BaseStoreOptions {
    deployID: string;
}
interface NamedStoreOptions extends BaseStoreOptions {
    name: string;
}
type StoreOptions = DeployStoreOptions | NamedStoreOptions;
interface SetOptions {
    /**
     * Accepts an absolute date as a `Date` object, or a relative date as the
     * number of seconds from the current date.
     */
    expiration?: Date | number;
}
declare class Store {
    private client;
    private name;
    constructor(options: StoreOptions);
    private static getExpirationHeaders;
    delete(key: string): Promise<void>;
    get(key: string): Promise<string>;
    get(key: string, { type }: {
        type: 'arrayBuffer';
    }): Promise<ArrayBuffer>;
    get(key: string, { type }: {
        type: 'blob';
    }): Promise<Blob>;
    get(key: string, { type }: {
        type: 'json';
    }): Promise<any>;
    get(key: string, { type }: {
        type: 'stream';
    }): Promise<ReadableStream>;
    get(key: string, { type }: {
        type: 'text';
    }): Promise<string>;
    set(key: string, data: BlobInput, { expiration }?: SetOptions): Promise<void>;
    setJSON(key: string, data: unknown, { expiration }?: SetOptions): Promise<void>;
}
interface GetStoreOptions extends Context {
    deployID?: string;
    fetch?: Fetcher;
    name?: string;
}
declare const getStore: {
    (name: string): Store;
    (options: GetStoreOptions): Store;
};

export { getStore };
